#!/bin/bash

set -e
set -x

PKGSGUI="xwayland xterm xfce4-terminal sway waybar mesa-utils lxpolkit wayland-protocols"

PKGSNET="iproute2 iptables iputils-ping ircii elinks isc-dhcp-client netcat-traditional net-tools network-manager nfacct ntp ntpdate rsync telnet traceroute wpasupplicant curl wget w3m rfkill ifupdown netbase openssh-client"

PKGSADMIN="apt apt-utils apt-listbugs apt-file cron cryptsetup lvm2 dbus-bin e2fsprogs fbset init-system-helpers ncdu parted pciutils policykit-1 procps sudo systemd systemd-sysv tmux u-boot-tools screen"

PKGSUTILS="busybox console-data console-setup cpio file flash-kernel gnupg gpgv htop kbd lm-sensors readline-common usbutils xdg-utils bsdmainutils less nano micro vim alsa-utils dosfstools python3-psutil"

PKGSMISC="brightnessctl brightness-udev ca-certificates debian-archive-keyring dialog gpm ncurses-term locales bash-completion man-db cryptsetup-initramfs linux-image-arm64 linux-headers-arm64 reform-tools reform-handbook"

mmdebstrap \
	--architectures=arm64 \
	--components=main \
	--variant="minbase" \
	--verbose \
	--include="$PKGSGUI $PKGSNET $PKGSADMIN $PKGSUTILS $PKGSMISC" \
	--skip=cleanup/reproducible \
	${comment#setup apt preferences} \
	--setup-hook='{ echo "Package: *"; echo "Pin: release n=reform, l=reform"; echo "Pin-Priority: 990"; } > "$1"/etc/apt/preferences.d/reform.pref' \
	${comment#setup flash-kernel} \
	--essential-hook='mkdir -p "$1"/etc/flash-kernel/ubootenv.d' \
	--essential-hook='mkdir -p "$1"/etc/flash-kernel/preboot.d' \
	--essential-hook='echo "MNT Reform 2" > "$1"/etc/flash-kernel/machine' \
	--essential-hook='{ echo /dev/mmcblk1p2 / auto errors=remount-ro 0 1; echo /dev/mmcblk1p1 /boot auto errors=remount-ro 0 1; } > "$1"/etc/fstab' \
	--essential-hook='{ echo LINUX_KERNEL_CMDLINE=\"console=ttymxc0,115200 console=tty1\"; echo LINUX_KERNEL_CMDLINE_DEFAULTS=\"ro no_console_suspend cma=512M pci=nomsi\"; } > "$1"/etc/default/flash-kernel' \
	${comment#select timezone} \
	--essential-hook='echo tzdata tzdata/Areas select Europe | chroot "$1" debconf-set-selections' \
	--essential-hook='echo tzdata tzdata/Zones/Europe select Berlin | chroot "$1" debconf-set-selections' \
	${comment#select locales} \
	--essential-hook='echo locales locales/default_environment_locale select en_US.UTF-8 | chroot "$1" debconf-set-selections' \
	--essential-hook='echo locales locales/locales_to_be_generated multiselect en_US.UTF-8 UTF-8 | chroot "$1" debconf-set-selections' \
	${comment#initramfs-tools} \
	--essential-hook='mkdir -p "$1"/etc/initramfs-tools' \
	--essential-hook='printf "pwm_imx27\nnwl-dsi\nti-sn65dsi86\nimx-dcss\npanel-edp\nmux-mmio\nmxsfb\nusbhid\nimx8mq-interconnect\n" > "$1"/etc/initramfs-tools/modules' \
	${comment#set up motd} \
	--customize-hook='rm -f "$1"/etc/motd' \
	--customize-hook='ln -s motd-rescue "$1"/etc/motd' \
	${comment#provide a copy of u-boot for (re)flashing} \
	--customize-hook='copy-in flash.bin /boot' \
	--customize-hook='chown -R root:root "$1"/boot/flash.bin' \
	${comment#populate root user and skel} \
	--customize-hook='echo '"'"'if [ $(whoami) == "root" ]; then cat /etc/reform-root-help; elif [ -z $WAYLAND_DISPLAY ]; then cat /etc/reform-help; fi'"'"' >> "$1"/etc/skel/.profile' \
	--customize-hook='chroot "$1" sh -c "rsync -Pha /etc/skel/ /root"' \
	${comment#populate /etc} \
	--customize-hook='echo reform > "$1"/etc/hostname' \
	--customize-hook='{ echo 127.0.0.1 localhost reform; echo ::1 localhost ip6-localhost ip6-loopback reform; echo ff02::1 ip6-allnodes; echo ff02::2 ip6-allrouters; } > "$1"/etc/hosts' \
	${comment#or else EXTRA_GROUPS doesnt work?} \
	--customize-hook='sed -i "s/^#EXTRA_GROUPS=.*/EXTRA_GROUPS=audio cdrom dip floppy video plugdev netdev/" "$1"/etc/adduser.conf' \
	--customize-hook='sed -i "s/^#ADD_EXTRA_GROUPS=.*/ADD_EXTRA_GROUPS=1/" "$1"/etc/adduser.conf' \
	${comment#remove root password -- using `passwd -d root` produces unreproducible output} \
	--customize-hook='echo "root:root" | chroot "$1" chpasswd' \
	--customize-hook='chroot "$1" sed -i "s/^root:[^:]\+:/root::/" /etc/shadow' \
	--customize-hook='rm "$1"/etc/resolv.conf' \
	--customize-hook='rm "$1"/var/lib/dbus/machine-id' ${comment#gets regenerated by dbus} \
	unstable target-userland.tar http://deb.debian.org/debian "deb [trusted=yes] https://mntre.com/reform-debian-repo reform main"
